@@ -18,7 +18,6 @@ from typing import (
 )
 
 import gym
-from gym.envs.mujoco import mujoco_env
 import numpy as np
 
 Step = Tuple[Any, Optional[float], bool, Mapping[str, Any]]
@@ -52,11 +51,7 @@ def make_env_fixture(
 
     Returns:
         A method to create Gym environments given their name.
-
-    # noqa: DAR301
-    # noqa: DAR401 gym.error.DependencyNotInstalled
     """
-    # TODO(adam): remove Darglint noqa once GH#132 closed
 
     def f(env_name: str) -> Iterator[gym.Env]:
         """Create environment `env_name`.
@@ -127,7 +122,19 @@ def has_same_observations(rollout_a: Rollout, rollout_b: Rollout) -> bool:
     """True if `rollout_a` and `rollout_b` have the same observations."""
     obs_list_a = [step[0] for step in rollout_a]
     obs_list_b = [step[0] for step in rollout_b]
-    return all(np.all(obs_a == obs_b) for obs_a, obs_b in zip(obs_list_a, obs_list_b))
+    if len(obs_list_a) != len(obs_list_b):  # pragma: no cover
+        return False
+    for obs_a, obs_b in zip(obs_list_a, obs_list_b):
+        if isinstance(obs_a, Mapping):  # pragma: no cover
+            if obs_a.keys() != obs_b.keys():
+                return False
+            obs_a = list(obs_a.values())
+            obs_b = list(obs_b.values())
+        else:
+            obs_a, obs_b = [obs_a], [obs_b]
+        if any([np.any(x != y) for x, y in zip(obs_a, obs_b)]):
+            return False
+    return True
 
 
 def test_seed(env: gym.Env, env_name: str, deterministic_envs: Iterable[str]) -> None:
@@ -188,6 +195,10 @@ def _sample_and_check(env: gym.Env, obs_space: gym.Space) -> bool:
     return done
 
 
+def _is_mujoco_env(env: gym.Env) -> bool:
+    return hasattr(env, "sim") and hasattr(env, "model")
+
+
 def test_rollout_schema(
     env: gym.Env,
     steps_after_done: int = 10,
@@ -234,7 +245,7 @@ def test_premature_step(env: gym.Env, skip_fn, raises_fn) -> None:
     Raises:
         AssertionError if test fails.
     """
-    if hasattr(env, "sim") and hasattr(env, "model"):  # pragma: no cover
+    if _is_mujoco_env(env):  # pragma: no cover
         # We can't use isinstance since importing mujoco_py will fail on
         # machines without MuJoCo installed
         skip_fn("MuJoCo environments cannot perform this check.")
@@ -278,7 +289,7 @@ def test_render(env: gym.Env, raises_fn) -> None:
         # on the viewer (commented out) so the resources are not released.
         # For now this is OK, but may bite if we end up testing a lot of
         # MuJoCo environments.
-        is_mujoco = isinstance(env.unwrapped, mujoco_env.MujocoEnv)
+        is_mujoco = _is_mujoco_env(env)
         if "rgb_array" in render_modes and not is_mujoco:
             # Render should not change without calling `step()`.
             # MuJoCo rendering fails this check, ignore -- not much we can do.
